@@ -1,11 +1,11 @@
-#!/usr/bin/python
+#!/usr/bin/python2.6
 # @package      hubzero-mailgateway
 # @file         mailproc.py
 # @author       David Benham <dbenham@purdue.edu>
-# @copyright    Copyright (c) 2012 HUBzero Foundation, LLC.
+# @copyright    Copyright (c) 2012-2013 HUBzero Foundation, LLC.
 # @license      http://www.gnu.org/licenses/lgpl-3.0.html LGPLv3
 #
-# Copyright (c) 2012 HUBzero Foundation, LLC.
+# Copyright (c) 2012-2013 HUBzero Foundation, LLC.
 #
 # This file is part of: The HUBzero(R) Platform for Scientific Collaboration
 #
@@ -37,6 +37,7 @@ import grp
 import hashlib
 import MySQLdb
 import os
+import pprint
 import pwd
 import re
 import smtplib
@@ -388,25 +389,42 @@ def extractMessageFromEmail(emailText):
 
 
 def getAttachments(emailText):
-	attachments = []
 	msg = email.message_from_string(emailText)
+	attachments = _getAttachments(msg)
+	return attachments
+
+
+def _getAttachments(msg_part):
 
 	acceptable = ['text/plain', 'image/png','image/jpg','image/jpeg','image/gif','image/tiff','application/pdf','application/msword','application/vnd.openxmlformats-officedocument.wordprocessingml.document']
 
-	for part in msg.walk():
-		if part.get_content_type() in acceptable:
-			attach = []
+	if msg_part.is_multipart():
+		# the base email returned by the python email parsing utils is a multipart 
+		# message that needs parsing. If multipart/alternative is set on the part, 
+		# that means this message part has multiple representaitons. This is generally
+		# used for including html *and* text versions of email and letting email clients
+		# decide which to display. It's possible for a given message part, to include
+		# a gif and a JPEG, but I'm assuming most email clients, when attaching a file
+		# to an email generally don't transcode the attachments, but just send them
+		if "multipart/alternative" not in msg_part.get_content_type():
+			attachments = []
+			for m in msg_part.get_payload():
+				a = _getAttachments(m)
+				if a:
+					attachments.append(a)
+			return attachments
+		else:
+			return None
+	else:
+		attach = []
+		attachedFilename = msg_part.get_filename()
+		# some attachments might not have associated filenames
+		if not attachedFilename:
+			attachedFilename = "attachment"
 
-			attachedFilename = part.get_filename()
-			# some attachments might not have associated filenames
-			if not attachedFilename:
-				attachedFilename = "attachment"
+		attach.append( [attachedFilename, msg_part.get_payload(decode=True)] )
 
-			attach.append(attachedFilename)
-			attach.append(part.get_payload(decode=True))
-			attachments.append(attach)
-
-	return attachments
+		return attach
 
 
 def saveAttachments(attachments, path):
@@ -474,7 +492,7 @@ def writeProcessedHeader(emailText):
 """
  Send email - just a wrapper
 """
-def sendEmail(toaddress, subject, messagetext, fromaddress = '', fromname = '', replytoaddress = '', envelope_from = ''):
+def sendEmail(toaddress, subject, messagetext, fromaddress = '', fromname = '', replytoaddress = '', envelope_from = '', additionalHeaders = None):
 
 	## Build outgoing email
 	msg = MIMEMultipart()
@@ -498,6 +516,13 @@ def sendEmail(toaddress, subject, messagetext, fromaddress = '', fromname = '',
 		msg['Reply-to'] = replytoaddress
 
 	textmsg = MIMEText(messagetext, 'plain', 'utf-8')
+
+	# add additional headers to the outgoing message
+	if additionalHeaders is not None:
+		for elem in additionalHeaders:
+			msg[elem] = additionalHeaders[elem]
+		
+	
 	msg.attach(textmsg)
 
 	server = smtplib.SMTP("localhost")
@@ -558,7 +583,7 @@ def cleanEmail(s):
 					tempMatch = re.search(regex1, line, re.S)
 
 					if tempMatch:
-						#print " match " + str(lc) + "> " + regex1 + "<>" + line + "<"
+						#print " match " + str(lc) + "@@" + regex1 + "@@ @@" + line + "@@"
 						matchFound = True
 						break
 
