@@ -1,11 +1,11 @@
-#!/usr/bin/python
+#!/usr/bin/python2.6
 # @package      hubzero-mailgateway
 # @file         processgroupforumpost.py
 # @author       David Benham <dbenham@purdue.edu>
-# @copyright    Copyright (c) 2012 HUBzero Foundation, LLC.
+# @copyright    Copyright (c) 2012-2013 HUBzero Foundation, LLC.
 # @license      http://www.gnu.org/licenses/lgpl-3.0.html LGPLv3
 #
-# Copyright (c) 2012 HUBzero Foundation, LLC.
+# Copyright (c) 2012-2013 HUBzero Foundation, LLC.
 #
 # This file is part of: The HUBzero(R) Platform for Scientific Collaboration
 #
@@ -101,19 +101,35 @@ try:
 
 			mailproc.log("Token " + hubtoken)
 
-			## Decrypt the hubtoken
+			# Decrypt the hubtoken
 			version, tokenType, userid, forum_post_id, timestamp = mailproc.decryptEmailToken(hubtoken)
 
-			## Lookup this jos_forum_posts record contained in the token
+			# Lookup this jos_forum_posts record contained in the token
 			mailproc.log("Looking up forum info for forum_post_id = " + str(forum_post_id))
 			db = mailproc.db_connect()
+			
+			# have to support multiple database schemas for this query
+			db = mailproc.db_connect()
 			cursor = db.cursor()
-			sql  = "SELECT jfp.`id`, jfp.`parent`, jfp.`scope_id`, jfp.`category_id`, jfp.`title` "
-			sql += "FROM jos_forum_posts jfp "
-			sql += "WHERE jfp.scope= 'group' AND jfp.id = %s "
+			sql = "SELECT count(1) FROM information_schema.COLUMNS WHERE TABLE_NAME = 'jos_forum_posts' AND COLUMN_NAME = 'scope'"
+			cursor.execute(sql)
+			rs = cursor.fetchone()			
 
+			# newer table version requires different lookups
+			if rs[0] == 1:
+				cursor = db.cursor()
+				sql  = "SELECT jfp.`id`, jfp.`parent`, jfp.`scope_id`, jfp.`category_id`, jfp.`title` "
+				sql += "FROM jos_forum_posts jfp "
+				sql += "WHERE jfp.id = %s "
+			else:
+				cursor = db.cursor()
+				sql  = "SELECT jfp.`id`, jfp.`parent`, jfp.`group_id`, jfp.`category_id`, jfp.`title` "
+				sql += "FROM jos_forum_posts jfp "
+				sql += "WHERE jfp.id = %s "
+				
 			data = (forum_post_id)
 			cursor.execute(sql, data)
+
 			rs = cursor.fetchone()
 
 			if not rs:
@@ -127,11 +143,11 @@ try:
 			cursor.close()
 			db.close()
 
-			## Look up group name
+			# Look up group name
 			mailproc.log("Looking up group informaiton on forum post for groupid " + str(groupid))
 			db = mailproc.db_connect()
 			cursor = db.cursor()
-			sql  = "SELECT xg.`description`, xg.`cn` FROM jos_xgroups xg WHERE xg.gidNumber = %s "
+			sql  = "SELECT xg.`description`, xg.`cn` FROM jos_xgroups xg WHERE xg.gidNumber = %s"
 			data = (groupid)
 			cursor.execute(sql, data)
 			rs = cursor.fetchone()
@@ -145,31 +161,57 @@ try:
 			cursor.close()
 			db.close()
 
-			## Do a database insert into the jos_xforum table
+			# Do a database insert into the jos_xforum table. Need to support multiple versions of this table, specifically
+			# the scope and thread fields are not always present
 			db = mailproc.db_connect()
-			cursor = db.cursor ()
-			sql = "INSERT INTO jos_forum_posts (`title`, `comment`, `created`, `created_by`, `state`, `sticky`, `parent`, `hits`, `scope`, `scope_id`, `access`, `anonymous`, `modified`, `modified_by`, `category_id`, `last_activity`) "
-			sql += "VALUES (%s, %s, %s, %s, %s, %s, %s, %s, %s, %s, %s, %s, %s, %s, %s, %s)"
+			cursor = db.cursor()
+			sql = "SELECT count(1) FROM information_schema.COLUMNS WHERE TABLE_NAME = 'jos_forum_posts' AND COLUMN_NAME = 'scope'"
+			cursor.execute(sql)
+			rs = cursor.fetchone()
+			if rs[0] == 1: 
+				scope_field = True 
+			else: 
+				scope_field = False
 
+			sql = "SELECT count(1) FROM information_schema.COLUMNS WHERE TABLE_NAME = 'jos_forum_posts' AND COLUMN_NAME = 'thread'"
+			cursor.execute(sql)
+			rs = cursor.fetchone()
+			if rs[0] == 1: 
+				thread_field = True 
+			else: 
+				thread_field = False
+
+			db = mailproc.db_connect()
+			cursor = db.cursor()
+			sql_fields = "INSERT INTO jos_forum_posts (`title`, `comment`, `created`, `created_by`, `state`, `sticky`, `parent`, `hits`, `access`, `anonymous`, `modified`, `modified_by`, `category_id`, `last_activity` "
+			sql_values = "VALUES (%s, %s, %s, %s, %s, %s, %s, %s, %s, %s, %s, %s, %s, %s"
 			data = ("Emailed forum response from " + emailFromAddress,
-			        userfeedback + "\n---- Emailed forum response from " + emailFromAddress,
-			        datetime.datetime.now(),
-			        userid,
-			        1,
-			        0,
-			        parent,
-			        0,
-				"group",
-			        groupid,
-			        4,
-			        0,
-			        datetime.datetime.now(),
-			        userid,
-					categoryid,
-			        datetime.datetime.now()
-				)
+				userfeedback + "\n---- Emailed forum response from " + emailFromAddress,
+				datetime.datetime.utcnow(), userid, 1, 0,
+				parent, 0, 4,
+				0, datetime.datetime.utcnow(), userid, categoryid,
+				datetime.datetime.utcnow())
 
-			cursor.execute (sql, data)
+			# add any necessary colums for all the different versions of this table bouncing around out there
+			if scope_field:
+				sql_fields += ", `scope`, `scope_id`"
+				sql_values += ", %s, %s"
+				data += ('group', groupid,)
+			else:
+				sql_fields += ", `group_id`"
+				sql_values += ", %s"
+				data += (groupid,)
+
+			if thread_field:
+				sql_fields += ", `thread`"
+				sql_values += ", %s"
+				data += (parent,)
+
+			# add final delimiters
+			sql_fields += ")"
+			sql_values += ")"
+
+			cursor.execute (sql_fields + " " + sql_values, data)
 			newCommentID = cursor.lastrowid
 			db.close()
 
